#####################################################################
# NAME: Chris Bilder                                                #
# DATE: 3-30-16                                                     #
# Purpose: Data summary with cereal data                            #
#                                                                   #
# NOTES:                                                            #
#####################################################################

#####################################################################
# Section 1

  cereal <- read.csv(file = "C:\\data\\cereal.csv")
  head(cereal)

  cereal$sugar <- cereal$sugar_g/cereal$size_g
  cereal$fat <- cereal$fat_g/cereal$size_g
  cereal$sodium <- cereal$sodium_mg/cereal$size_g
  head(cereal)

  cereal$sugar_g[1]/cereal$size_g[1]

  nrow(cereal)

#####################################################################
# Section 2

  #Mean by shelf
  aggregate(formula = sugar ~ Shelf, data = cereal, FUN = mean)
  #Standard deviation by shelf
  aggregate(formula = sugar ~ Shelf, data = cereal, FUN = sd)

  mod.fit <- aov(formula = sugar ~ factor(Shelf), data = cereal)
  mod.fit$coefficients

  library(knitr)
  names(opts_chunk)
  opts_chunk$set

  knit_theme$get()


#####################################################################
# Section 3

  mod.fit <- aov(formula = sugar ~ factor(Shelf), data = cereal)
  summary(mod.fit)


#####################################################################
# Section 4

  boxplot(formula = sugar ~ Shelf, data = cereal, main = "Box and dot plot", ylab = "Sugar", xlab = "Shelf",
    pars = list(outpch=NA))
  stripchart(x = cereal$sugar ~ cereal$Shelf, lwd = 2, col = "red", method = "jitter", vertical = TRUE,
    pch = 1, add = TRUE)
  #Example showing that the plot is shown before this code
  cereal[cereal$Cereal == "Kellog's Razzle Dazzle Rice Crispies",]$sugar

  library(MASS)
  shelf.color <- rep(x = c("black", "red", "green", "blue"), each = 10)
  par(mar = c(2, 4, 1, 2))
  parcoord(x = cereal[,c(1,8:10)], col = shelf.color)
  legend(x = 1.4, y = 1, legend = c("1", "2", "3", "4"), lty = c(1,1,1,1), col=c("black", "red", "green3", "blue"),
    bty = "n", cex = 0.75)


#####################################################################
# Section 5

  # Code in ExternalCode.R


#####################################################################
# Section 6

  save.Tukey <- TukeyHSD(x = mod.fit, conf.level = 0.90)
  save.Tukey


#####################################################################
# Section 7

  save.mean <- aggregate(formula = sugar ~ Shelf, data = cereal, FUN = mean)
  save.sd <- aggregate(formula = sugar ~ Shelf, data = cereal, FUN = sd)
  save.table <- data.frame(Shelf = save.mean$Shelf, Mean = round(save.mean$sugar,2), SD = round(save.sd$sugar,2))
  print(save.table, row.names = FALSE)

  # Code does not work in R 3.2.2
  library(gridExtra)
  g <- tableGrob(d = save.table, show.rownames = FALSE)
  library(grid)
  grid.draw(g)

  library(xtable)
  print(xtable(save.table, caption = "Table created using the xtable package.",
    label = "xtable1"), caption.placement = "top", floating = TRUE, include.rownames = FALSE)













  #